Credits
=======

Project lead
------------

* Mark Piper

Contributors
------------

* Eric Hutton
* Mark Piper

Acknowledgments
---------------

This work is supported by the National Science Foundation under Award No.
[2026951](https://www.nsf.gov/awardsearch/showAward?AWD_ID=2026951),
*EarthCube Capabilities: Cloud-Based Accessible and Reproducible Modeling for Water and Sediment Research*.
